<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS language="ko" version="2.1">
<context>
    <name>AboutDlg</name>
    <message>
        <source>About</source>
        <translation>정보</translation>
    </message>
</context>
<context>
    <name>AddNewTorrentDialog</name>
    <message>
        <source>Category:</source>
        <translation>카테고리:</translation>
    </message>
    <message>
        <source>Start torrent</source>
        <translation>토런트 시작</translation>
    </message>
    <message>
        <source>Skip hash check</source>
        <translation>해쉬 검사 건너뛰기</translation>
    </message>
    <message>
        <source>Create subfolder</source>
        <translation>하위 폴더 만들기</translation>
    </message>
    <message>
        <source>Torrent Management Mode:</source>
        <translation>토런트 관리 모드:</translation>
    </message>
</context>
<context>
    <name>CategoryFilterModel</name>
    <message>
        <source>All</source>
        <translation>전체</translation>
    </message>
    <message>
        <source>Uncategorized</source>
        <translation>카테고리 없음</translation>
    </message>
</context>
<context>
    <name>CategoryFilterWidget</name>
    <message>
        <source>Add category...</source>
        <translation>카테고리 추가...</translation>
    </message>
    <message>
        <source>Remove category</source>
        <translation>카테고리 제거</translation>
    </message>
    <message>
        <source>Remove unused categories</source>
        <translation>사용하지 않는 카테고리 제거</translation>
    </message>
    <message>
        <source>Resume torrents</source>
        <translation>토런트 재시작</translation>
    </message>
    <message>
        <source>Pause torrents</source>
        <translation>토런트 일시중지</translation>
    </message>
    <message>
        <source>Delete torrents</source>
        <translation>토런트 삭제</translation>
    </message>
    <message>
        <source>New Category</source>
        <translation>새 카테고리</translation>
    </message>
    <message>
        <source>Edit category...</source>
        <translation>카테고리 편집...</translation>
    </message>
</context>
<context>
    <name>HttpServer</name>
    <message>
        <source>Exit qBittorrent</source>
        <translation>큐빗토런트 종료</translation>
    </message>
    <message>
        <source>Only one link per line</source>
        <translation>한 줄에 링크 한개씩</translation>
    </message>
    <message>
        <source>Global upload rate limit must be greater than 0 or disabled.</source>
        <translation>전역 업로드 비율 제한은 0보다 높거나 비활성화되어야 합니다.</translation>
    </message>
    <message>
        <source>Global download rate limit must be greater than 0 or disabled.</source>
        <translation>전역 다운로드 비율 제한은 0보다 높거나 비활성화되어야 합니다.</translation>
    </message>
    <message>
        <source>Alternative upload rate limit must be greater than 0 or disabled.</source>
        <translation>대체 올리기 비율 제한은 0보다 높거나 비활성화되어야 합니다.</translation>
    </message>
    <message>
        <source>Alternative download rate limit must be greater than 0 or disabled.</source>
        <translation>대체 다운로드 비율 제한은 0보다 크거나 비활성화해야 합니다.</translation>
    </message>
    <message>
        <source>Maximum active downloads must be greater than -1.</source>
        <translation>최대 활성 다운로드는 -1보다 커야 합니다.</translation>
    </message>
    <message>
        <source>Maximum active uploads must be greater than -1.</source>
        <translation>최대 활성 업로드는 -1보다 커야 합니다.</translation>
    </message>
    <message>
        <source>Maximum active torrents must be greater than -1.</source>
        <translation>최대 활성 토런트는 -1보다 커야 합니다.</translation>
    </message>
    <message>
        <source>Maximum number of connections limit must be greater than 0 or disabled.</source>
        <translation>최대 연결 제한 수는 0보다 높거나 비활성화되어야 합니다.</translation>
    </message>
    <message>
        <source>Maximum number of connections per torrent limit must be greater than 0 or disabled.</source>
        <translation>토런트당 최대 연결 제한 수는 0보다 높거나 비활성화되어야 합니다.</translation>
    </message>
    <message>
        <source>Maximum number of upload slots per torrent limit must be greater than 0 or disabled.</source>
        <translation>토런트당 최대 업로드 슬롯 제한 수는 0보다 높거나 비활성화되어야 합니다.</translation>
    </message>
    <message>
        <source>Unable to save program preferences, qBittorrent is probably unreachable.</source>
        <translation>프로그램 환경설정을 저장할 수 없습니다. 큐빗토런트에 접근이 불가능한 상태인 것 같습니다.</translation>
    </message>
    <message>
        <source>IRC: #qbittorrent on Freenode</source>
        <translation>IRC: Freenode의 #qbittorrent 채널</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>알 수 없음</translation>
    </message>
    <message>
        <source>Share ratio limit must be between 0 and 9998.</source>
        <translation>공유 비율 제한은 반드시 0에서 9998 사이여야 합니다.</translation>
    </message>
    <message>
        <source>Seeding time limit must be between 0 and 525600 minutes.</source>
        <translation>배포 시간 제한은 반드시 0에서 525600분 사이여야 합니다.</translation>
    </message>
    <message>
        <source>The port used for incoming connections must be between 1 and 65535.</source>
        <translation>들어오는 연결에 사용하는 포트는 1 ~ 65535 사이여야 합니다.</translation>
    </message>
    <message>
        <source>The port used for the Web UI must be between 1 and 65535.</source>
        <translation>웹 UI에 사용하는 포트는 1 ~ 65535 사이여야 합니다.</translation>
    </message>
    <message>
        <source>Unable to log in, qBittorrent is probably unreachable.</source>
        <translation>로그인 할 수 없습니다. 큐빗토런트에 접근할 수 없는 것 같습니다.</translation>
    </message>
    <message>
        <source>Invalid Username or Password.</source>
        <translation>무효한 사용자명/비밀번호입니다.</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>사용자명</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>비밀번호</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>로그인</translation>
    </message>
    <message>
        <source>Original authors</source>
        <translation>원래 제작자</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>적용</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>추가</translation>
    </message>
    <message>
        <source>Upload Torrents</source>
        <comment>Upload torrent files to qBittorent using WebUI</comment>
        <translation>토런트 업로드</translation>
    </message>
    <message>
        <source>Save files to location:</source>
        <translation>파일 저장 위치:</translation>
    </message>
    <message>
        <source>Cookie:</source>
        <translation>쿠키:</translation>
    </message>
    <message>
        <source>Type folder here</source>
        <translation>여기에 폴더 입력</translation>
    </message>
    <message>
        <source>More information</source>
        <translation>추가 정보</translation>
    </message>
    <message>
        <source>Information about certificates</source>
        <translation>인증 정보</translation>
    </message>
    <message>
        <source>Set location</source>
        <translation>설정 위치</translation>
    </message>
    <message>
        <source>Limit upload rate</source>
        <translation>업로드 속도 제한</translation>
    </message>
    <message>
        <source>Limit download rate</source>
        <translation>다운로드 속도 제한</translation>
    </message>
    <message>
        <source>Rename torrent</source>
        <translation>토런트 이름 변경</translation>
    </message>
    <message>
        <source>Other...</source>
        <comment>Save Files to: Watch Folder / Default Folder / Other...</comment>
        <translation>기타...</translation>
    </message>
    <message>
        <source>Monday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>월요일</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>화요일</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>수요일</translation>
    </message>
    <message>
        <source>Thursday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>목요일</translation>
    </message>
    <message>
        <source>Friday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>금요일</translation>
    </message>
    <message>
        <source>Saturday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>토요일</translation>
    </message>
    <message>
        <source>Sunday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>일요일</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>로그아웃</translation>
    </message>
    <message>
        <source>Download Torrents from their URLs or Magnet links</source>
        <translation>URL이나 마그넷 링크에서 토런트 다운로드</translation>
    </message>
    <message>
        <source>Upload local torrent</source>
        <translation>로컬 토런트 업로드</translation>
    </message>
    <message>
        <source>Are you sure you want to delete the selected torrents from the transfer list?</source>
        <translation>선택하신 토런트를 전송 목록에서 삭제하시겠습니까?</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>저장</translation>
    </message>
    <message>
        <source>qBittorrent client is not reachable</source>
        <translation>큐빗토런트 클라이언트에 접근할 수 없습니다</translation>
    </message>
    <message>
        <source>Global number of upload slots limit must be greater than 0 or disabled.</source>
        <translation>전역 업로드 슬롯 제한은 0보다 높거나 비활성화되어야 합니다.</translation>
    </message>
    <message>
        <source>Invalid category name:\nPlease do not use any special characters in the category name.</source>
        <translation>무효한 카테고리 이름:\n카테고리 이름은 특수 문자를 사용하지 마십시오.</translation>
    </message>
    <message>
        <source>Unable to create category</source>
        <translation>카테고리를 만들 수 없습니다</translation>
    </message>
    <message>
        <source>Upload rate threshold must be greater than 0.</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Edit</source>
        <translation>편집</translation>
    </message>
    <message>
        <source>Free space: %1</source>
        <translation>여유 공간: %1</translation>
    </message>
    <message>
        <source>Torrent inactivity timer must be greater than 0.</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Saving Management</source>
        <translation>저장 관리</translation>
    </message>
    <message>
        <source>Download rate threshold must be greater than 0.</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>qBittorrent has been shutdown</source>
        <translation>큐빗토런트를 종료했습니다</translation>
    </message>
    <message>
        <source>JavaScript Required! You must enable JavaScript for the Web UI to work properly</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Edit</source>
        <translation>편집</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>도구</translation>
    </message>
    <message>
        <source>File</source>
        <translation>파일</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>도움말</translation>
    </message>
    <message>
        <source>View</source>
        <translation>보기</translation>
    </message>
    <message>
        <source>Options...</source>
        <translation>옵션...</translation>
    </message>
    <message>
        <source>Resume</source>
        <translation>재시작</translation>
    </message>
    <message>
        <source>Minimum Priority</source>
        <translation>최저 우선 순위</translation>
    </message>
    <message>
        <source>Top Priority</source>
        <translation>최고 우선 순위</translation>
    </message>
    <message>
        <source>Decrease Priority</source>
        <translation>우선 순위 낮추기</translation>
    </message>
    <message>
        <source>Increase Priority</source>
        <translation>우선 순위 높이기</translation>
    </message>
    <message>
        <source>Top Toolbar</source>
        <translation>상단 도구바</translation>
    </message>
    <message>
        <source>Status Bar</source>
        <translation>상태 표시줄</translation>
    </message>
    <message>
        <source>Speed in Title Bar</source>
        <translation>제목 표시줄에 속도</translation>
    </message>
    <message>
        <source>Donate!</source>
        <translation>기부</translation>
    </message>
    <message>
        <source>Resume All</source>
        <translation>모두 재시작</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>통계</translation>
    </message>
    <message>
        <source>About</source>
        <translation>정보</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>일시중지</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>삭제</translation>
    </message>
    <message>
        <source>Pause All</source>
        <translation>모두 일시중지</translation>
    </message>
    <message>
        <source>Add Torrent File...</source>
        <translation>토런트 파일 추가...</translation>
    </message>
    <message>
        <source>Documentation</source>
        <translation>문서</translation>
    </message>
    <message>
        <source>Add Torrent Link...</source>
        <translation>토런트 링크 추가...</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>예</translation>
    </message>
    <message>
        <source>No</source>
        <translation>아니오</translation>
    </message>
    <message>
        <source>Global Upload Speed Limit</source>
        <translation>전역 업로드 속도 제한</translation>
    </message>
    <message>
        <source>Global Download Speed Limit</source>
        <translation>전역 다운로드 속도 제한</translation>
    </message>
    <message>
        <source>Are you sure you want to quit qBittorrent?</source>
        <translation>큐빗토런트를 종료할까요?</translation>
    </message>
    <message>
        <source>[D: %1, U: %2] qBittorrent %3</source>
        <comment>D = Download; U = Upload; %3 is qBittorrent version</comment>
        <translation>[D: %1, U: %2] 큐빗토런트 %3</translation>
    </message>
    <message>
        <source>Alternative speed limits</source>
        <translation>대체 속도 제한</translation>
    </message>
    <message>
        <source>Search Engine</source>
        <translation>검색 엔진</translation>
    </message>
    <message>
        <source>Filter torrent list...</source>
        <translation>토런트 목록 필터하기...</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>검색</translation>
    </message>
    <message>
        <source>Transfers</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>옵션</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>다운로드</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation>연결</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>속도</translation>
    </message>
    <message>
        <source>BitTorrent</source>
        <translation>비트토런트</translation>
    </message>
    <message>
        <source>Web UI</source>
        <translation>웹 UI</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>언어</translation>
    </message>
    <message>
        <source>User Interface Language:</source>
        <translation>사용자 인터페이스 언어:</translation>
    </message>
    <message>
        <source>Email notification upon download completion</source>
        <translation>다운로드 완료시 이메일로 알리기</translation>
    </message>
    <message>
        <source>Run external program on torrent completion</source>
        <translation>토런트 완료시 외부 프로그램 실행하기</translation>
    </message>
    <message>
        <source>IP Filtering</source>
        <translation>IP 필터링</translation>
    </message>
    <message>
        <source>Schedule the use of alternative rate limits</source>
        <translation>대체 속도 제한 사용 일정 계획</translation>
    </message>
    <message>
        <source>Torrent Queueing</source>
        <translation>토런트 대기열</translation>
    </message>
    <message>
        <source>Seed torrents until their seeding time reaches</source>
        <translation>토런트 배포 시간이</translation>
    </message>
    <message>
        <source>Automatically add these trackers to new downloads:</source>
        <translation>다음 트래커를 새 다운로드에 자동으로 추가:</translation>
    </message>
    <message>
        <source>Web User Interface (Remote control)</source>
        <translation>웹 사용자 인터페이스 (원격 제어)</translation>
    </message>
    <message>
        <source>IP address:</source>
        <translation>IP 주소:</translation>
    </message>
    <message>
        <source>Server domains:</source>
        <translation>서버 도메인:</translation>
    </message>
    <message>
        <source>Use HTTPS instead of HTTP</source>
        <translation>HTTP 대신에 HTTPS 사용하기</translation>
    </message>
    <message>
        <source>Bypass authentication for clients on localhost</source>
        <translation>로컬호스트의 클라이언트에 대해 인증 우회하기</translation>
    </message>
    <message>
        <source>Bypass authentication for clients in whitelisted IP subnets</source>
        <translation>허용된 IP 서브넷의 클라이언트에 대해 인증 우회하기</translation>
    </message>
    <message>
        <source>Update my dynamic domain name</source>
        <translation>내 동적 도메인 이름 업데이트하기</translation>
    </message>
    <message>
        <source>Keep incomplete torrents in:</source>
        <translation>미완료 토런트 보관하기:</translation>
    </message>
    <message>
        <source>Copy .torrent files to:</source>
        <translation>.torrent 파일 복사하기:</translation>
    </message>
    <message>
        <source>Copy .torrent files for finished downloads to:</source>
        <translation>다 받은 후 .torrent 복사하기:</translation>
    </message>
    <message>
        <source>Pre-allocate disk space for all files</source>
        <translation>모든 파일에 디스크 공간 미리 할당하기</translation>
    </message>
    <message>
        <source>Append .!qB extension to incomplete files</source>
        <translation>미완료 파일에 .!qB 확장자 덧붙이기</translation>
    </message>
    <message>
        <source>Automatically add torrents from:</source>
        <translation>다음 경로의 토런트 자동 추가:</translation>
    </message>
    <message>
        <source>SMTP server:</source>
        <translation>SMTP 서버:</translation>
    </message>
    <message>
        <source>This server requires a secure connection (SSL)</source>
        <translation>이 서버는 보안 연결이 필요합니다 (SSL)</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>인증</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>사용자명:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>비밀번호:</translation>
    </message>
    <message>
        <source>Enabled protocol:</source>
        <translation>활성화된 프로토콜:</translation>
    </message>
    <message>
        <source>TCP and μTP</source>
        <translation>TCP 및 μTP</translation>
    </message>
    <message>
        <source>Listening Port</source>
        <translation>수신 포트</translation>
    </message>
    <message>
        <source>Port used for incoming connections:</source>
        <translation>들어오는 연결 포트:</translation>
    </message>
    <message>
        <source>Use UPnP / NAT-PMP port forwarding from my router</source>
        <translation>내 라우터에서 UPnp / NAT-PMP 포트 포워딩 사용하기</translation>
    </message>
    <message>
        <source>Use different port on each startup</source>
        <translation>시작할 때마다 다른 포트 사용하기</translation>
    </message>
    <message>
        <source>Connections Limits</source>
        <translation>연결 제한</translation>
    </message>
    <message>
        <source>Maximum number of connections per torrent:</source>
        <translation>토런트당 최대 연결 수:</translation>
    </message>
    <message>
        <source>Global maximum number of connections:</source>
        <translation>전역 최대 연결 수:</translation>
    </message>
    <message>
        <source>Maximum number of upload slots per torrent:</source>
        <translation>토런트당 최대 업로드 슬롯 수:</translation>
    </message>
    <message>
        <source>Global maximum number of upload slots:</source>
        <translation>전역 최대 업로드 슬롯 수:</translation>
    </message>
    <message>
        <source>Proxy Server</source>
        <translation>프록시 서버</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>형식:</translation>
    </message>
    <message>
        <source>(None)</source>
        <translation>(없음)</translation>
    </message>
    <message>
        <source>SOCKS4</source>
        <translation>SOCKS4</translation>
    </message>
    <message>
        <source>SOCKS5</source>
        <translation>SOCKS5</translation>
    </message>
    <message>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation>호스트:</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>포트:</translation>
    </message>
    <message>
        <source>Use proxy for peer connections</source>
        <translation>피어 연결에 프록시 사용하기</translation>
    </message>
    <message>
        <source>Disable connections not supported by proxies</source>
        <translation>프록시가 지원하지 않는 연결 비활성화하기</translation>
    </message>
    <message>
        <source>Use proxy only for torrents</source>
        <translation>토런트에 프록시만 사용하기</translation>
    </message>
    <message>
        <source>Filter path (.dat, .p2p, .p2b):</source>
        <translation>필터 경로(.dat, .p2p, .p2b):</translation>
    </message>
    <message>
        <source>Manually banned IP addresses...</source>
        <translation>직접 금지한 IP 주소...</translation>
    </message>
    <message>
        <source>Apply to trackers</source>
        <translation>트래커에 적용하기</translation>
    </message>
    <message>
        <source>Global Rate Limits</source>
        <translation>전역 속도 제한</translation>
    </message>
    <message>
        <source>Upload:</source>
        <translation>업로드:</translation>
    </message>
    <message>
        <source>Download:</source>
        <translation>다운로드:</translation>
    </message>
    <message>
        <source>Alternative Rate Limits</source>
        <translation>대체 속도 제한</translation>
    </message>
    <message>
        <source>From:</source>
        <extracomment>from (time1 to time2)</extracomment>
        <translation>보낸이:</translation>
    </message>
    <message>
        <source>To:</source>
        <extracomment>time1 to time2</extracomment>
        <translation>받는이:</translation>
    </message>
    <message>
        <source>When:</source>
        <translation>언제:</translation>
    </message>
    <message>
        <source>Every day</source>
        <translation>매일</translation>
    </message>
    <message>
        <source>Weekdays</source>
        <translation>주중</translation>
    </message>
    <message>
        <source>Weekends</source>
        <translation>주말</translation>
    </message>
    <message>
        <source>Rate Limits Settings</source>
        <translation>속도 제한 설정</translation>
    </message>
    <message>
        <source>Apply rate limit to transport overhead</source>
        <translation>전송 오버헤드에 속도 제한 적용하기</translation>
    </message>
    <message>
        <source>Apply rate limit to µTP protocol</source>
        <translation>μTP 프로토콜에 속도 제한 적용하기</translation>
    </message>
    <message>
        <source>Privacy</source>
        <translation>개인 정보</translation>
    </message>
    <message>
        <source>Enable DHT (decentralized network) to find more peers</source>
        <translation>DHT(분산 네트워크)를 사용하여 더 많은 피어 찾기</translation>
    </message>
    <message>
        <source>Enable Peer Exchange (PeX) to find more peers</source>
        <translation>피어 교환(PeX)을 사용하여 더 많은 피어 찾기</translation>
    </message>
    <message>
        <source>Enable Local Peer Discovery to find more peers</source>
        <translation>더 많은 피어 검색을 위해 로컬 피어 찾기 활성화하기</translation>
    </message>
    <message>
        <source>Encryption mode:</source>
        <translation>암호화 모드:</translation>
    </message>
    <message>
        <source>Prefer encryption</source>
        <translation>암호화 선호하기</translation>
    </message>
    <message>
        <source>Require encryption</source>
        <translation>암호화 요구하기</translation>
    </message>
    <message>
        <source>Disable encryption</source>
        <translation>암호화 끄기</translation>
    </message>
    <message>
        <source>Enable anonymous mode</source>
        <translation>익명 모드 사용하기</translation>
    </message>
    <message>
        <source>Maximum active downloads:</source>
        <translation>최대 활성 다운로드:</translation>
    </message>
    <message>
        <source>Maximum active uploads:</source>
        <translation>최대 활성 업로드:</translation>
    </message>
    <message>
        <source>Maximum active torrents:</source>
        <translation>최대 활성 토런트:</translation>
    </message>
    <message>
        <source>Do not count slow torrents in these limits</source>
        <translation>이 제한에 느린 토런트는 셈하지 않기</translation>
    </message>
    <message>
        <source>Share Ratio Limiting</source>
        <translation>공유 비율 제한</translation>
    </message>
    <message>
        <source>Seed torrents until their ratio reaches</source>
        <translation>토런트 배포 비율이 </translation>
    </message>
    <message>
        <source>then</source>
        <translation>에 도달하면</translation>
    </message>
    <message>
        <source>Pause them</source>
        <translation>일시 중지하기</translation>
    </message>
    <message>
        <source>Remove them</source>
        <translation>제거하기</translation>
    </message>
    <message>
        <source>Use UPnP / NAT-PMP to forward the port from my router</source>
        <translation>내 라우터의 포트를 포워드하기 위해 UPnP / NAT-PMP 사용하기</translation>
    </message>
    <message>
        <source>Certificate:</source>
        <translation>인증서:</translation>
    </message>
    <message>
        <source>Key:</source>
        <translation>키:</translation>
    </message>
    <message>
        <source>Register</source>
        <translation>등록하기</translation>
    </message>
    <message>
        <source>Domain name:</source>
        <translation>도메인명:</translation>
    </message>
    <message>
        <source>Supported parameters (case sensitive):</source>
        <translation>지원되는 변수 (대소문자 구분):</translation>
    </message>
    <message>
        <source>%N: Torrent name</source>
        <translation>%N: 토런트 이름</translation>
    </message>
    <message>
        <source>%L: Category</source>
        <translation>%L: 카테고리</translation>
    </message>
    <message>
        <source>%G: Tags (seperated by comma)</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>%F: Content path (same as root path for multifile torrent)</source>
        <translation>%F: 컨텐츠 경로 (복수 파일 토런트에 대해 루트 경로와 같은)</translation>
    </message>
    <message>
        <source>%R: Root path (first torrent subdirectory path)</source>
        <translation>%R: 루트 경로 (첫 번째 토런트 하위 폴더 경로)</translation>
    </message>
    <message>
        <source>%D: Save path</source>
        <translation>%D: 저장 경로</translation>
    </message>
    <message>
        <source>%C: Number of files</source>
        <translation>%C: 파일 개수</translation>
    </message>
    <message>
        <source>%Z: Torrent size (bytes)</source>
        <translation>%Z: 토런트 크기 (바이트)</translation>
    </message>
    <message>
        <source>%T: Current tracker</source>
        <translation>%T: 현재 트래커</translation>
    </message>
    <message>
        <source>%I: Info hash</source>
        <translation>%I: 정보 해쉬</translation>
    </message>
    <message>
        <source>Tip: Encapsulate parameter with quotation marks to avoid text being cut off at whitespace (e.g., "%N")</source>
        <translation>팁: 텍스트가 공백에서 잘리지 않게 하려면 변수를 따옴표로 둘러싸세요 (예, "%N")</translation>
    </message>
    <message>
        <source>The Web UI username must be at least 3 characters long.</source>
        <translation>웹 UI 사용자명은 최소한 세 문자 이상이어야 합니다.</translation>
    </message>
    <message>
        <source>The Web UI password must be at least 6 characters long.</source>
        <translation>웹 UI 비밀번호는 최소한 여섯 문자 이상이어야 합니다.</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>분</translation>
    </message>
    <message>
        <source>KiB/s</source>
        <translation>KiB/초</translation>
    </message>
    <message>
        <source>Enable clickjacking protection</source>
        <translation>클릭 재킹 보호 활성화</translation>
    </message>
    <message>
        <source>Enable Cross-Site Request Forgery (CSRF) protection</source>
        <translation>크로스 사이트 요청 위조 (CSRF) 보호 활성화</translation>
    </message>
    <message>
        <source>Delete .torrent files afterwards</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Download rate threshold:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Upload rate threshold:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Change current password</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Automatic</source>
        <translation>자동</translation>
    </message>
    <message>
        <source>Use alternative Web UI</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Default Save Path:</source>
        <translation>기본 저장 경로:</translation>
    </message>
    <message>
        <source>The alternative Web UI files location cannot be blank.</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Do not start the download automatically</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Switch torrent to Manual Mode</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>When Torrent Category changed:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Relocate affected torrents</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Apply rate limit to peers on LAN</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>0 means unlimited</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Relocate torrent</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>When Default Save Path changed:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Enable Host header validation</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Security</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>When Category Save Path changed:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Create subfolder for torrents with multiple files</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>seconds</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Switch affected torrents to Manual Mode</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Files location:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Manual</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Torrent inactivity timer:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Default Torrent Management Mode:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>When adding a torrent</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>PeerListWidget</name>
    <message>
        <source>IP</source>
        <translation>IP</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>포트</translation>
    </message>
    <message>
        <source>Flags</source>
        <translation>플래그</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation>연결</translation>
    </message>
    <message>
        <source>Client</source>
        <comment>i.e.: Client application</comment>
        <translation>클라이언트</translation>
    </message>
    <message>
        <source>Progress</source>
        <comment>i.e: % downloaded</comment>
        <translation>진행</translation>
    </message>
    <message>
        <source>Down Speed</source>
        <comment>i.e: Download speed</comment>
        <translation>다운 속도</translation>
    </message>
    <message>
        <source>Up Speed</source>
        <comment>i.e: Upload speed</comment>
        <translation>업 속도</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <comment>i.e: total data downloaded</comment>
        <translation>받음</translation>
    </message>
    <message>
        <source>Uploaded</source>
        <comment>i.e: total data uploaded</comment>
        <translation>올림</translation>
    </message>
    <message>
        <source>Relevance</source>
        <comment>i.e: How relevant this peer is to us. How many pieces it has that we don't.</comment>
        <translation>관련성</translation>
    </message>
    <message>
        <source>Files</source>
        <comment>i.e. files that are being downloaded right now</comment>
        <translation>파일</translation>
    </message>
    <message>
        <source>Country</source>
        <translation>국가</translation>
    </message>
</context>
<context>
    <name>PropListDelegate</name>
    <message>
        <source>Normal</source>
        <comment>Normal (priority)</comment>
        <translation>보통</translation>
    </message>
    <message>
        <source>High</source>
        <comment>High (priority)</comment>
        <translation>높음</translation>
    </message>
    <message>
        <source>Maximum</source>
        <comment>Maximum (priority)</comment>
        <translation>최대</translation>
    </message>
</context>
<context>
    <name>PropTabBar</name>
    <message>
        <source>General</source>
        <translation>일반</translation>
    </message>
    <message>
        <source>Trackers</source>
        <translation>트래커</translation>
    </message>
    <message>
        <source>Peers</source>
        <translation>피어</translation>
    </message>
    <message>
        <source>HTTP Sources</source>
        <translation>HTTP 소스</translation>
    </message>
    <message>
        <source>Content</source>
        <translation>내용</translation>
    </message>
</context>
<context>
    <name>PropertiesWidget</name>
    <message>
        <source>Downloaded:</source>
        <translation>다운로드:</translation>
    </message>
    <message>
        <source>Transfer</source>
        <translation>전송</translation>
    </message>
    <message>
        <source>Time Active:</source>
        <extracomment>Time (duration) the torrent is active (not paused)</extracomment>
        <translation>활성 시간:</translation>
    </message>
    <message>
        <source>ETA:</source>
        <translation>남은 시간:</translation>
    </message>
    <message>
        <source>Uploaded:</source>
        <translation>업로드:</translation>
    </message>
    <message>
        <source>Seeds:</source>
        <translation>시드:</translation>
    </message>
    <message>
        <source>Download Speed:</source>
        <translation>다운로드 속도:</translation>
    </message>
    <message>
        <source>Upload Speed:</source>
        <translation>업로드 속도:</translation>
    </message>
    <message>
        <source>Peers:</source>
        <translation>피어:</translation>
    </message>
    <message>
        <source>Download Limit:</source>
        <translation>다운로드 제한:</translation>
    </message>
    <message>
        <source>Upload Limit:</source>
        <translation>업로드 제한:</translation>
    </message>
    <message>
        <source>Wasted:</source>
        <translation>버림:</translation>
    </message>
    <message>
        <source>Connections:</source>
        <translation>연결:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>정보</translation>
    </message>
    <message>
        <source>Comment:</source>
        <translation>코멘트:</translation>
    </message>
    <message>
        <source>Share Ratio:</source>
        <translation>공유 비율:</translation>
    </message>
    <message>
        <source>Reannounce In:</source>
        <translation>재알림 시간:</translation>
    </message>
    <message>
        <source>Last Seen Complete:</source>
        <translation>최근 완료:</translation>
    </message>
    <message>
        <source>Total Size:</source>
        <translation>전체 크기:</translation>
    </message>
    <message>
        <source>Pieces:</source>
        <translation>조각:</translation>
    </message>
    <message>
        <source>Created By:</source>
        <translation>만든이:</translation>
    </message>
    <message>
        <source>Added On:</source>
        <translation>추가일:</translation>
    </message>
    <message>
        <source>Completed On:</source>
        <translation>완료일:</translation>
    </message>
    <message>
        <source>Created On:</source>
        <translation>생성일:</translation>
    </message>
    <message>
        <source>Torrent Hash:</source>
        <translation>토런트 해쉬:</translation>
    </message>
    <message>
        <source>Save Path:</source>
        <translation>저장 경로:</translation>
    </message>
    <message>
        <source>Never</source>
        <translation>절대 안함</translation>
    </message>
    <message>
        <source>%1 x %2 (have %3)</source>
        <comment>(torrent pieces) eg 152 x 4MB (have 25)</comment>
        <translation>%1 x %2 (%3 개 있음)</translation>
    </message>
    <message>
        <source>%1 (%2 this session)</source>
        <translation>%1(%2 현재 세션)</translation>
    </message>
    <message>
        <source>%1 (%2 max)</source>
        <comment>%1 and %2 are numbers, e.g. 3 (10 max)</comment>
        <translation>%1 (최대 %2)</translation>
    </message>
    <message>
        <source>%1 (%2 total)</source>
        <comment>%1 and %2 are numbers, e.g. 3 (10 total)</comment>
        <translation>%1 (전체 %2)</translation>
    </message>
    <message>
        <source>%1 (%2 avg.)</source>
        <comment>%1 and %2 are speed rates, e.g. 200KiB/s (100KiB/s avg.)</comment>
        <translation>%1 (평균 %2)</translation>
    </message>
    <message>
        <source>Download limit:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Upload limit:</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>ScanFoldersModel</name>
    <message>
        <source>Monitored Folder</source>
        <translation>감시 폴더</translation>
    </message>
    <message>
        <source>Override Save Location</source>
        <translation>저장 위치</translation>
    </message>
    <message>
        <source>Monitored folder</source>
        <translation>감시 폴더</translation>
    </message>
    <message>
        <source>Default save location</source>
        <translation>기본 저장 위치</translation>
    </message>
</context>
<context>
    <name>SpeedLimitDialog</name>
    <message>
        <source>KiB/s</source>
        <translation>KiB/초</translation>
    </message>
</context>
<context>
    <name>StatsDialog</name>
    <message>
        <source>Statistics</source>
        <translation>통계</translation>
    </message>
    <message>
        <source>User statistics</source>
        <translation>사용자 통계</translation>
    </message>
    <message>
        <source>Cache statistics</source>
        <translation>캐쉬 통계</translation>
    </message>
    <message>
        <source>Read cache hits:</source>
        <translation>읽기 캐쉬 적중:</translation>
    </message>
    <message>
        <source>Average time in queue:</source>
        <translation>대기열의 평균 시간:</translation>
    </message>
    <message>
        <source>Connected peers:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>All-time share ratio:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>All-time download:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Session waste:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>All-time upload:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Total buffer size:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Performance statistics</source>
        <translation>성능 통계</translation>
    </message>
    <message>
        <source>Queued I/O jobs:</source>
        <translation>대기중 I/O 작업:</translation>
    </message>
    <message>
        <source>Write cache overload:</source>
        <translation>쓰기 캐쉬 과부하:</translation>
    </message>
    <message>
        <source>Read cache overload:</source>
        <translation>읽기 캐쉬 과부하:</translation>
    </message>
    <message>
        <source>Total queued size:</source>
        <translation>총 대기열 크기:</translation>
    </message>
</context>
<context>
    <name>StatusBar</name>
    <message>
        <source>DHT: %1 nodes</source>
        <translation>DHT: %1 노드</translation>
    </message>
</context>
<context>
    <name>StatusFilterWidget</name>
    <message>
        <source>All (0)</source>
        <comment>this is for the status filter</comment>
        <translation>전체 (0)</translation>
    </message>
    <message>
        <source>Downloading (0)</source>
        <translation>받는 중 (0)</translation>
    </message>
    <message>
        <source>Seeding (0)</source>
        <translation>배포 중 (0)</translation>
    </message>
    <message>
        <source>Completed (0)</source>
        <translation>완료 (0)</translation>
    </message>
    <message>
        <source>Resumed (0)</source>
        <translation>재시작 (0)</translation>
    </message>
    <message>
        <source>Paused (0)</source>
        <translation>일시중지 (0)</translation>
    </message>
    <message>
        <source>Active (0)</source>
        <translation>활성 (0)</translation>
    </message>
    <message>
        <source>Inactive (0)</source>
        <translation>비활성 (0)</translation>
    </message>
    <message>
        <source>Errored (0)</source>
        <translation>오류 (0)</translation>
    </message>
    <message>
        <source>All (%1)</source>
        <translation>전체 (%1)</translation>
    </message>
    <message>
        <source>Downloading (%1)</source>
        <translation>받는 중 (%1)</translation>
    </message>
    <message>
        <source>Seeding (%1)</source>
        <translation>배포 중 (%1)</translation>
    </message>
    <message>
        <source>Completed (%1)</source>
        <translation>완료 (%1)</translation>
    </message>
    <message>
        <source>Paused (%1)</source>
        <translation>일시중지 (%1)</translation>
    </message>
    <message>
        <source>Resumed (%1)</source>
        <translation>재시작 (%1)</translation>
    </message>
    <message>
        <source>Active (%1)</source>
        <translation>활성 (%1)</translation>
    </message>
    <message>
        <source>Inactive (%1)</source>
        <translation>비활성 (%1)</translation>
    </message>
    <message>
        <source>Errored (%1)</source>
        <translation>오류 (%1)</translation>
    </message>
</context>
<context>
    <name>TorrentContentModel</name>
    <message>
        <source>Name</source>
        <translation>이름</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>크기</translation>
    </message>
    <message>
        <source>Progress</source>
        <translation>진행</translation>
    </message>
    <message>
        <source>Download Priority</source>
        <translation>다운로드 우선순위</translation>
    </message>
    <message>
        <source>Remaining</source>
        <translation>남음</translation>
    </message>
    <message>
        <source>Availability</source>
        <translation>가용성:</translation>
    </message>
</context>
<context>
    <name>TransferListModel</name>
    <message>
        <source>Name</source>
        <comment>i.e: torrent name</comment>
        <translation>이름</translation>
    </message>
    <message>
        <source>Size</source>
        <comment>i.e: torrent size</comment>
        <translation>크기</translation>
    </message>
    <message>
        <source>Done</source>
        <comment>% Done</comment>
        <translation>완료</translation>
    </message>
    <message>
        <source>Status</source>
        <comment>Torrent status (e.g. downloading, seeding, paused)</comment>
        <translation>상태</translation>
    </message>
    <message>
        <source>Seeds</source>
        <comment>i.e. full sources (often untranslated)</comment>
        <translation>시드</translation>
    </message>
    <message>
        <source>Peers</source>
        <comment>i.e. partial sources (often untranslated)</comment>
        <translation>피어</translation>
    </message>
    <message>
        <source>Down Speed</source>
        <comment>i.e: Download speed</comment>
        <translation>다운 속도</translation>
    </message>
    <message>
        <source>Up Speed</source>
        <comment>i.e: Upload speed</comment>
        <translation>업 속도</translation>
    </message>
    <message>
        <source>Ratio</source>
        <comment>Share ratio</comment>
        <translation>비율</translation>
    </message>
    <message>
        <source>ETA</source>
        <comment>i.e: Estimated Time of Arrival / Time left</comment>
        <translation>남은 시간</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>카테고리</translation>
    </message>
    <message>
        <source>Tags</source>
        <translation>태그</translation>
    </message>
    <message>
        <source>Added On</source>
        <comment>Torrent was added to transfer list on 01/01/2010 08:00</comment>
        <translation>추가일</translation>
    </message>
    <message>
        <source>Completed On</source>
        <comment>Torrent was completed on 01/01/2010 08:00</comment>
        <translation>완료일</translation>
    </message>
    <message>
        <source>Tracker</source>
        <translation>트래커</translation>
    </message>
    <message>
        <source>Down Limit</source>
        <comment>i.e: Download limit</comment>
        <translation>다운 제한</translation>
    </message>
    <message>
        <source>Up Limit</source>
        <comment>i.e: Upload limit</comment>
        <translation>업 제한</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <comment>Amount of data downloaded (e.g. in MB)</comment>
        <translation>받음</translation>
    </message>
    <message>
        <source>Uploaded</source>
        <comment>Amount of data uploaded (e.g. in MB)</comment>
        <translation>올림</translation>
    </message>
    <message>
        <source>Session Download</source>
        <comment>Amount of data downloaded since program open (e.g. in MB)</comment>
        <translation>세션 다운로드</translation>
    </message>
    <message>
        <source>Session Upload</source>
        <comment>Amount of data uploaded since program open (e.g. in MB)</comment>
        <translation>세션 업로드</translation>
    </message>
    <message>
        <source>Remaining</source>
        <comment>Amount of data left to download (e.g. in MB)</comment>
        <translation>남음</translation>
    </message>
    <message>
        <source>Time Active</source>
        <comment>Time (duration) the torrent is active (not paused)</comment>
        <translation>활성 시간</translation>
    </message>
    <message>
        <source>Save path</source>
        <comment>Torrent save path</comment>
        <translation>저장 경로</translation>
    </message>
    <message>
        <source>Completed</source>
        <comment>Amount of data completed (e.g. in MB)</comment>
        <translation>완료됨</translation>
    </message>
    <message>
        <source>Ratio Limit</source>
        <comment>Upload share ratio limit</comment>
        <translation>속도 제한</translation>
    </message>
    <message>
        <source>Last Seen Complete</source>
        <comment>Indicates the time when the torrent was last seen complete/whole</comment>
        <translation>최근 본 완료</translation>
    </message>
    <message>
        <source>Last Activity</source>
        <comment>Time passed since a chunk was downloaded/uploaded</comment>
        <translation>최근 활동</translation>
    </message>
    <message>
        <source>Total Size</source>
        <comment>i.e. Size including unwanted data</comment>
        <translation>총 크기</translation>
    </message>
</context>
<context>
    <name>TrackerListWidget</name>
    <message>
        <source>URL</source>
        <translation>URL</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>상태</translation>
    </message>
    <message>
        <source>Peers</source>
        <translation>피어</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>메시지</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Tracker URL:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Updating...</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Working</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Disabled</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Not contacted yet</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>#</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>N/A</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Seeds</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Not working</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Copy tracker URL</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Add a new tracker...</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Edit tracker URL...</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Tracker editing</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Leeches</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Remove tracker</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>TrackersAdditionDialog</name>
    <message>
        <source>Trackers addition dialog</source>
        <translation>트래커 추가 대화상자</translation>
    </message>
    <message>
        <source>List of trackers to add (one per line):</source>
        <translation>추가할 트래커 목록 (한 줄에 하나씩):</translation>
    </message>
</context>
<context>
    <name>TransferListDelegate</name>
    <message>
        <source>%1 ago</source>
        <comment>e.g.: 1h 20m ago</comment>
        <translation>%1 전</translation>
    </message>
    <message>
        <source>Allocating</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Paused</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Completed</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Moving</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>[F] Seeding</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Seeding</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Queued</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Errored</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>[F] Downloading</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Downloading metadata</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Checking</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Missing Files</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Queued for checking</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Downloading</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Checking resume data</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Stalled</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>TransferListFiltersWidget</name>
    <message>
        <source>Status</source>
        <translation>상태</translation>
    </message>
    <message>
        <source>Categories</source>
        <translation>카테고리</translation>
    </message>
</context>
<context>
    <name>TransferListWidget</name>
    <message>
        <source>Torrent Download Speed Limiting</source>
        <translation>토런트 다운로드 속도 제한</translation>
    </message>
    <message>
        <source>Torrent Upload Speed Limiting</source>
        <translation>토런트 업로드 속도 제한</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>이름 바꾸기</translation>
    </message>
    <message>
        <source>Resume</source>
        <comment>Resume/start the torrent</comment>
        <translation>재시작</translation>
    </message>
    <message>
        <source>Force Resume</source>
        <comment>Force Resume/start the torrent</comment>
        <translation>강제 재시작</translation>
    </message>
    <message>
        <source>Pause</source>
        <comment>Pause the torrent</comment>
        <translation>일시중지</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>Delete the torrent</comment>
        <translation>삭제</translation>
    </message>
    <message>
        <source>Limit share ratio...</source>
        <translation>공유 비율 제한...</translation>
    </message>
    <message>
        <source>Limit upload rate...</source>
        <translation>업로드 속도 제한...</translation>
    </message>
    <message>
        <source>Limit download rate...</source>
        <translation>다운로드 속도 제한...</translation>
    </message>
    <message>
        <source>Move up</source>
        <comment>i.e. move up in the queue</comment>
        <translation>위로 이동</translation>
    </message>
    <message>
        <source>Move down</source>
        <comment>i.e. Move down in the queue</comment>
        <translation>아래로 이동</translation>
    </message>
    <message>
        <source>Move to top</source>
        <comment>i.e. Move to top of the queue</comment>
        <translation>최상단으로 이동</translation>
    </message>
    <message>
        <source>Move to bottom</source>
        <comment>i.e. Move to bottom of the queue</comment>
        <translation>최하단으로 이동</translation>
    </message>
    <message>
        <source>Set location...</source>
        <translation>위치 지정...</translation>
    </message>
    <message>
        <source>Copy name</source>
        <translation>이름 복사</translation>
    </message>
    <message>
        <source>Copy hash</source>
        <translation>복사 해쉬</translation>
    </message>
    <message>
        <source>Download first and last pieces first</source>
        <translation>첫 번째와 마지막 조각을 먼저 다운로드</translation>
    </message>
    <message>
        <source>Automatic Torrent Management</source>
        <translation>자동 토런트 관리</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>카테고리</translation>
    </message>
    <message>
        <source>New...</source>
        <comment>New category...</comment>
        <translation>새...</translation>
    </message>
    <message>
        <source>Reset</source>
        <comment>Reset category</comment>
        <translation>초기화</translation>
    </message>
    <message>
        <source>Priority</source>
        <translation>우선순위</translation>
    </message>
    <message>
        <source>Force recheck</source>
        <translation>강제로 다시 검사</translation>
    </message>
    <message>
        <source>Copy magnet link</source>
        <translation>마그넷 링크 복사</translation>
    </message>
    <message>
        <source>Super seeding mode</source>
        <translation>수퍼 배포 모드</translation>
    </message>
    <message>
        <source>Rename...</source>
        <translation>이름 바꾸기...</translation>
    </message>
    <message>
        <source>Download in sequential order</source>
        <translation>차례대로 받기</translation>
    </message>
    <message>
        <source>Force Recheck</source>
        <translation>강제로 다시 검사</translation>
    </message>
    <message>
        <source>New Category</source>
        <translation>새 카테고리</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>위치</translation>
    </message>
    <message>
        <source>New name</source>
        <translation>새 이름</translation>
    </message>
    <message>
        <source>Set location</source>
        <translation>위치 지정</translation>
    </message>
    <message>
        <source>Force reannounce</source>
        <translation>강제로 다시 알리기</translation>
    </message>
    <message>
        <source>Edit Category</source>
        <translation>카테고리 편집</translation>
    </message>
    <message>
        <source>Save path</source>
        <translation>저장 경로</translation>
    </message>
</context>
<context>
    <name>UpDownRatioDialog</name>
    <message>
        <source>Torrent Upload/Download Ratio Limiting</source>
        <translation>토런트 업로드/다운로드 비율 제한</translation>
    </message>
    <message>
        <source>Use global share limit</source>
        <translation>전역 공유 한계 사용하기</translation>
    </message>
    <message>
        <source>Set no share limit</source>
        <translation>공유 한계 없음 설정하기</translation>
    </message>
    <message>
        <source>Set share limit to</source>
        <translation>공유 한계 제한:</translation>
    </message>
    <message>
        <source>ratio</source>
        <translation>비율</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>분</translation>
    </message>
</context>
<context>
    <name>about</name>
    <message>
        <source>An advanced BitTorrent client programmed in C++, based on Qt toolkit and libtorrent-rasterbar.</source>
        <translation>Qt 툴킷과 libtorrent-rasterbar를 기반으로하는 C++로 작성된 비트토런트 클라이언트입니다.</translation>
    </message>
    <message>
        <source>Home Page:</source>
        <translation>홈페이지:</translation>
    </message>
    <message>
        <source>Forum:</source>
        <translation>포럼:</translation>
    </message>
    <message>
        <source>Bug Tracker:</source>
        <translation>버그 트래커:</translation>
    </message>
</context>
<context>
    <name>confirmDeletionDlg</name>
    <message>
        <source>Deletion confirmation</source>
        <translation>삭제 확인</translation>
    </message>
    <message>
        <source>Also delete the files on the hard disk</source>
        <translation>하드 디스크상의 파일도 삭제하기</translation>
    </message>
    <message>
        <source>Deletion confirmation - qBittorrent</source>
        <translation>삭제 확인 - qBittorrent</translation>
    </message>
</context>
<context>
    <name>downloadFromURL</name>
    <message>
        <source>Download from URLs</source>
        <translation>URL에서 다운로드</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>다운로드</translation>
    </message>
    <message>
        <source>Add Torrent Links</source>
        <translation>토런트 링크 추가</translation>
    </message>
</context>
<context>
    <name>misc</name>
    <message>
        <source>B</source>
        <comment>bytes</comment>
        <translation>B</translation>
    </message>
    <message>
        <source>KiB</source>
        <comment>kibibytes (1024 bytes)</comment>
        <translation>KiB</translation>
    </message>
    <message>
        <source>MiB</source>
        <comment>mebibytes (1024 kibibytes)</comment>
        <translation>MiB</translation>
    </message>
    <message>
        <source>GiB</source>
        <comment>gibibytes (1024 mibibytes)</comment>
        <translation>GiB</translation>
    </message>
    <message>
        <source>TiB</source>
        <comment>tebibytes (1024 gibibytes)</comment>
        <translation>TiB</translation>
    </message>
    <message>
        <source>PiB</source>
        <comment>pebibytes (1024 tebibytes)</comment>
        <translation>PiB</translation>
    </message>
    <message>
        <source>EiB</source>
        <comment>exbibytes (1024 pebibytes)</comment>
        <translation>EiB</translation>
    </message>
    <message>
        <source>/s</source>
        <comment>per second</comment>
        <translation>/초</translation>
    </message>
    <message>
        <source>%1h %2m</source>
        <comment>e.g: 3hours 5minutes</comment>
        <translation>%1시 %2분</translation>
    </message>
    <message>
        <source>%1d %2h</source>
        <comment>e.g: 2days 10hours</comment>
        <translation>%1일 %2시</translation>
    </message>
    <message>
        <source>Unknown</source>
        <comment>Unknown (size)</comment>
        <translation>알 수 없음</translation>
    </message>
    <message>
        <source>&lt; 1m</source>
        <comment>&lt; 1 minute</comment>
        <translation>&lt; 1분</translation>
    </message>
    <message>
        <source>%1m</source>
        <comment>e.g: 10minutes</comment>
        <translation>%1분</translation>
    </message>
</context>
<context>
    <name>TorrentsController</name>
    <message>
        <source>Save path is empty</source>
        <translation>저장 경로가 비어 있습니다</translation>
    </message>
</context>
<context>
    <name>PluginSourceDlg</name>
    <message>
        <source>Cancel</source>
        <translation>취소</translation>
    </message>
    <message>
        <source>Plugin path:</source>
        <translation>플러그인 경로:</translation>
    </message>
    <message>
        <source>URL or local directory</source>
        <translation>URL 또는 로컬 디렉토리</translation>
    </message>
    <message>
        <source>Install plugin</source>
        <translation>플러그인 설치</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>SearchEngineWidget</name>
    <message>
        <source>Seeds:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>All plugins</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Size:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Stop</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Search</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Search plugins...</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>All categories</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Search in:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Copy description page URL</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Go to description page</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Results (showing</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Download</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Filter</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Torrent names only</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Only enabled</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>out of</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Everywhere</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>PluginSelectDlg</name>
    <message>
        <source>Uninstall</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Install new plugin</source>
        <translation>새 플러그인 설치</translation>
    </message>
    <message>
        <source>You can get new search engine plugins here:</source>
        <translation>이곳에서 새로운 검색 엔진 플러그인을 얻을 수 있습니다:</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>닫기</translation>
    </message>
    <message>
        <source>Installed search plugins:</source>
        <translation>설치한 검색 플러그인:</translation>
    </message>
    <message>
        <source>Enabled</source>
        <translation>활성화됨</translation>
    </message>
    <message>
        <source>Warning: Be sure to comply with your country's copyright laws when downloading torrents from any of these search engines.</source>
        <translation>경고: 이러한 검색 엔진에서 토런트를 받을 때는 해당 국가의 저작권법을 준수해야 합니다.</translation>
    </message>
    <message>
        <source>Check for updates</source>
        <translation>업데이트 확인</translation>
    </message>
    <message>
        <source>Search plugins</source>
        <translation>검색 플러그인</translation>
    </message>
</context>
<context>
    <name>SearchResultsTable</name>
    <message>
        <source>Name</source>
        <translation>이름</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>크기</translation>
    </message>
    <message>
        <source>Leechers</source>
        <translation>공유자</translation>
    </message>
    <message>
        <source>Search engine</source>
        <translation>검색 엔진</translation>
    </message>
    <message>
        <source>Seeders</source>
        <translation>배포자</translation>
    </message>
</context>
<context>
    <name>SearchPluginsTable</name>
    <message>
        <source>Name</source>
        <translation>이름</translation>
    </message>
    <message>
        <source>Url</source>
        <translation>URL</translation>
    </message>
    <message>
        <source>Enabled</source>
        <translation>활성화됨</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>버전</translation>
    </message>
</context>
</TS>